multidim.fast_algorithms — GDA Toolbox v1.0 Manual

# multidim.fast_algorithms

This Cython module contains core algorithms for multidimensional data. In particular, some distance caching and the cover-tree friends matching.

If a function requires its own explicit iterator in a loop, probably it should go here. Anything that is just a vectorized operation in NumPy or Pandas can go in plain python elsewhere.

See http://docs.cython.org/src/tutorial/np.html for ideas on writing efficient code in Cython.

This module is compiled by either of these commands
  - `python setup.py install` (as called by `pip` for standard installation and use)
  - `python setup.py build_ext --inplace` (as run by developers for code testing)

## Notes

Automatically-generated online documentation will never see the C-only functions that are defined with `cdef` in Cython, as shown in http://cython.readthedocs.io/en/latest/src/reference/extension_types.html Because of the limitations of Sphinx, you’ll have to simply view the sourcecode for further information. For this module, these C-only functions include

> - `is_partition_bool()`
> - `is_partition_list()`

## Copyright

- This file is part of https://github.com/geomdata/gda-public/
- 2015, 2016, 2017 by Geometric Data Analytics, Inc. (http://geomdata.com)
- AGPL license. See LICENSE or https://github.com/geomdata/gda-public/blob/master/LICENSE

Functions

`check_heights` | Verify that cells of dimension dim have weight greater than their boundaries of dimension dim - 1.
`covertree_adopt_or_liberate` | adopt an orphan using type-1 friends.
`covertree_befriend321` | Set friends3 using inheritance filter
`covertree_exchange_teens` | For a given center of a CoverTree, determine which of its children are
`distance_cache_None` | Get bulk distances, using no storage cache.
`distance_cache_dict` | Get bulk distances, using dictionary storage cache.
`distance_cache_dok` | Get bulk distances, using dictionary storage cache.
`distance_cache_numpy` | Get bulk distances, using NumPy storage cache.
`edges_from_dists` |
`entropy` | Compute the base-N entropy of normalized bins [bin0, bin1, …, bin(N-1)]
`gaussian` | Generate value for a multivariate Gaussian PDF.
`gaussian_fit` | Fit a normalized Gaussian to this cloud using singular value decomposition.
`gaussian_fit_wt` | Fit a normalized Gaussian to this cloud using singular value decomposition, with weights on the points.
`is_partition_bool` | Check that bigblock is partitioned by list_of_small_blocks
`is_partition_list` | You have a big list and a list of small lists.
`label_means` | Given a list of points, a list of labels, and a list of weights, compute the weighted mean for each label.
`label_weights` | Weights-per-label of a subset with labels and weights.

### Table of Contents

- multidim.fast_algorithms
  - Notes
  - Copyright

#### Previous topic

multidim.covertree.CoverLevel.plot_data_title

#### Next topic

multidim.models